fwtnp(input, f, inputtype = "points", nkeep = 2, intercept = TRUE,
initboundhandl = "reflect", updateboundhandl = "add", neighbours = 1,
closest = FALSE, LocalPred = LinearPred)"reflect" - the intervals corresponding to the first and last datapoints are taken to have the respective grid values as midpoints; and "PointsUpdate), when the removed point is on the boundaryy: "reflect" makes the neighbouring interLinearPred, QuadPred, CubicPred, AdaptPred and AdaptNeigh.LocalPred=AdaptNeigh.AdaptNeigh, AdaptPred, CubicPred, fwtnpmp, invtnp, LinearPred, QuadPred#
# Generate some one-dimensional data: 100 observations.
#
input <- runif(100)
f <- input^2 - 3*input
#
# Compute fwtnp function on this data
#
out <- fwtnp(input,f,LocalPred=AdaptPred,neighbours=2,closest=TRUE)
#
# That's it.
#Run the code above in your browser using DataLab